import{_ as b}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Bhh1Qoi3.js";import{A as h}from"./constants-C-_YHHgQ.js";import{e as v,b as w,V as A,J as r,f as x,x as d,q as p,j as _,C as t,s as e,$ as C,aO as f,D as I,S as a,T as u,k as T,aQ as B,K as D,g as c,ar as N}from"./jwt-decode.esm-rEBc1yJt.js";import{u as S}from"./workspaceStore-CXj1KaxZ.js";import{C as E}from"./index-D9LKNmUT.js";import"./logo-BiWG9_W5.js";import"./Logo-BC2emGhq.js";import"./userStore-DeXNkqIg.js";import"./runnerData-BmXXoqqr.js";import"./url-XyebHjIS.js";import"./colorHelpers-9BGi_4OL.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new $().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="8dadd38e-54ae-40b9-8182-d51c64e63a45",o._sentryDebugIdIdentifier="sentry-dbid-8dadd38e-54ae-40b9-8182-d51c64e63a45")}catch{}})();const V={class:"inner-content"},R={class:"card-content"},H=v({__name:"Error",setup(o){const i=A(),g=D(),m=S(),y=w(()=>m.state.workspace?.name??m.state.workspace?.brandName),n=w(()=>{const{status:l}=i.params;switch(l){case"404":return{status:l,title:r.translate("i18n_page_not_found"),message:r.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:l,title:r.translate("i18n_access_denied"),message:r.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:r.translate("i18n_internal_error"),message:r.translate("i18n_internal_error_message"),showAd:!1}}}),k=()=>{g.push({name:"playerHome"})};return(l,s)=>(c(),x("div",V,[d(e(C),null,{default:t(()=>[a(u(n.value.title),1)]),_:1}),d(e(f),{class:"message"},{default:t(()=>[a(u(n.value.message),1)]),_:1}),n.value.action?(c(),p(e(I),{key:0,type:"link",onClick:k},{default:t(()=>[a(u(n.value.action),1)]),_:1})):_("",!0),n.value.showAd?(c(),p(e(E),{key:1,bordered:!1,class:"card"},{default:t(()=>[T("div",R,[d(b,{style:{"margin-bottom":"10px"}}),d(e(f),null,{default:t(()=>[a("This page is part of "+u(y.value?`the ${y.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(m).state.workspace?(c(),p(e(f),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),d(e(B),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):_("",!0)])]),_:1})):_("",!0)]))}}),$=N(H,[["__scopeId","data-v-522ad0d4"]]);export{$ as default};
//# sourceMappingURL=Error-Bt5tfBNi.js.map
