import{A as n}from"./index-CqNRy1DZ.js";import{e as r,b as o,f as a,j as f,t as c,x as d,s as l,g as p,ar as i}from"./jwt-decode.esm-rEBc1yJt.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5f5e5845-71e1-4106-8ffa-d387b3706ef2",e._sentryDebugIdIdentifier="sentry-dbid-5f5e5845-71e1-4106-8ffa-d387b3706ef2")}catch{}})();const u=r({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,y)=>e.stepsInfo?(p(),a("nav",{key:0,class:c(["p-steps",{"full-screen":!e.isPreview}])},[d(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):f("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-TR6GZ6v3.js.map
