import{_ as r}from"./logo-BiWG9_W5.js";import{L as s}from"./Logo-BC2emGhq.js";import{e as o,q as i,s as a,g as d}from"./jwt-decode.esm-rEBc1yJt.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f0c7f42c-9e16-4b91-98b3-06c2dee747b6",e._sentryDebugIdIdentifier="sentry-dbid-f0c7f42c-9e16-4b91-98b3-06c2dee747b6")}catch{}})();const l=o({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(d(),i(s,{"image-url":a(r),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{l as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-Bhh1Qoi3.js.map
