.role-readonly[data-v-a0f92666]{color:var(--ac-text-secondary);font-size:13px;padding:0 4px}.role-trigger[data-v-a0f92666]{padding:0 6px;color:var(--ac-text-secondary);display:inline-flex;align-items:center;gap:4px}.role-overlay[data-v-a0f92666]{background:var(--ac-bg-secondary);border:1px solid var(--ac-border-primary);border-radius:8px;padding:6px;display:flex;flex-direction:column;gap:6px;min-width:150px;box-shadow:0 6px 16px #0000002e}.role-options[data-v-a0f92666]{list-style:none;margin:0;padding:0;display:flex;flex-direction:column}.role-option[data-v-a0f92666]{display:flex;align-items:center;gap:8px;padding:6px 8px;border-radius:6px;cursor:pointer;color:var(--ac-text-primary);font-size:13px}.role-option[data-v-a0f92666]:hover{background:var(--ac-bg-tertiary, rgba(255, 255, 255, .06))}.role-option.is-selected[data-v-a0f92666]{color:var(--ac-brand-primary)}.role-option__check[data-v-a0f92666]{width:14px;height:14px;flex-shrink:0;display:inline-flex;align-items:center;justify-content:center}.role-overlay__actions[data-v-a0f92666]{display:flex;justify-content:flex-end;gap:6px;padding:6px 4px 2px;border-top:1px solid var(--ac-border-primary)}.editors-page[data-v-fac8f687]{padding:24px 0;max-width:720px;margin:0 auto}.editors-header[data-v-fac8f687]{display:flex;flex-direction:column;gap:4px;margin-bottom:24px}.editors-page__item[data-v-fac8f687]{align-items:center}.editors-page__row[data-v-fac8f687]{display:flex;align-items:center;gap:12px;flex:1;min-width:0}.editors-page__email[data-v-fac8f687]{font-weight:400;color:var(--ac-text-primary);overflow:hidden;text-overflow:ellipsis;white-space:nowrap}[data-v-fac8f687] .ant-list-item-action{display:inline-flex;align-items:center;gap:8px}[data-v-fac8f687] .ant-list-item-action .ant-btn{display:inline-flex;align-items:center;justify-content:center}
