.org-connections-page[data-v-3c05ef0a]{padding:24px 0;max-width:920px;margin:0 auto}.org-connections-header[data-v-3c05ef0a]{display:flex;flex-direction:column;gap:4px;margin-bottom:24px}.org-connections-name[data-v-3c05ef0a]{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.org-connections-warning[data-v-3c05ef0a]{color:#d97706;flex-shrink:0}.org-connections-visibility[data-v-3c05ef0a],.org-connections-menu-trigger[data-v-3c05ef0a]{display:inline-flex;align-items:center;justify-content:center;background:transparent;border:none;padding:4px;cursor:pointer;color:var(--ac-text-tertiary, #6b7280);flex-shrink:0}.org-connections-visibility[data-v-3c05ef0a]:hover:not(:disabled),.org-connections-menu-trigger[data-v-3c05ef0a]:hover:not(:disabled){color:var(--ac-text-primary, #111827)}.org-connections-visibility[data-v-3c05ef0a]:disabled,.org-connections-menu-trigger[data-v-3c05ef0a]:disabled{cursor:default}.org-connections-chip[data-v-3c05ef0a]{cursor:pointer}
