import{_ as s}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Bhh1Qoi3.js";import{L as i}from"./CircularLoading-C_mYUEPg.js";import{e as c,K as d,n as l,f as u,g as f,x as n,C as _,k as p,T as h,s as w,J as m,ar as g}from"./jwt-decode.esm-rEBc1yJt.js";import{a as b}from"./router-BaFu-do7.js";import"./logo-BiWG9_W5.js";import"./Logo-BC2emGhq.js";import"./ts.worker-BI7fZ7sa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1c285786-6229-47d9-ba2e-24052d55f29b",e._sentryDebugIdIdentifier="sentry-dbid-1c285786-6229-47d9-ba2e-24052d55f29b")}catch{}})();const y=e=>{const a=new URLSearchParams(e.replace(/^#/,"")),t=a.get("jwt"),o=a.get("error"),r={};return t&&(r.jwt=t),o&&(r.error=o),r},k={class:"oauth-callback"},I={class:"message"},x=c({__name:"OAuthCallback",setup(e){const a=d();return l(async()=>{const{jwt:t,error:o}=y(window.location.hash);if(window.location.hash&&window.history.replaceState(null,"",window.location.pathname+window.location.search),o||!t){await a.push({name:"login",query:{error:o??"oidc_login_failed"}});return}if(!b.saveJWT(t)){await a.push({name:"login",query:{error:"oidc_login_failed"}});return}await a.push({path:"/"})}),(t,o)=>(f(),u("div",k,[n(s,{"hide-text":"",size:"large"}),n(i,{direction:"column",justify:"center"},{default:_(()=>[p("span",I,h(w(m).translate("i18n_auth_authenticating")),1)]),_:1})]))}}),q=g(x,[["__scopeId","data-v-dcad4324"]]);export{q as default};
//# sourceMappingURL=OAuthCallback-BOI1UQZ1.js.map
