import{O as t}from"./os-D8ZgIrNR.js";import"./jwt-decode.esm-rEBc1yJt.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="00a5759a-1bf4-417b-ac73-c7080bb9a17b",e._sentryDebugIdIdentifier="sentry-dbid-00a5759a-1bf4-417b-ac73-c7080bb9a17b")}catch{}})();const b=e=>t.isMac?e.metaKey:e.ctrlKey,d=e=>e.shiftKey;export{b as c,d as s};
//# sourceMappingURL=keyboard-BB3polz3.js.map
