.scrollable-body[data-v-6b6964f8]{max-height:50vh;overflow-y:auto;margin:0 -8px;padding:4px 8px}.scrollable-body[data-v-6b6964f8] .ant-form-item:last-child{margin-bottom:0}.form-footer[data-v-6b6964f8]{margin-top:16px}.request-form[data-v-6b6964f8]{margin-top:8px}.request-form[data-v-6b6964f8] .ant-form-item{margin-bottom:16px}.request-intro[data-v-6b6964f8]{margin:0!important;line-height:1.5}.recipient-emails-label[data-v-6b6964f8]{display:block;font-size:13px;font-weight:500;color:var(--ac-text-primary, #262626);margin-bottom:2px}.request-info-alert[data-v-6b6964f8]{padding:6px 10px}.request-info-alert[data-v-6b6964f8] .ant-alert-message{font-size:12px;line-height:1.4}.request-info-alert[data-v-6b6964f8] .ant-alert-icon{font-size:12px}.auth-footer[data-v-6b6964f8]{display:flex;flex-direction:column;align-items:stretch;gap:10px}.request-fallback[data-v-6b6964f8]{font-size:12px;color:var(--ac-text-secondary, #8c8c8c);text-align:center;margin:3px 0}.request-fallback-link[data-v-6b6964f8]{color:var(--ac-brand-primary, #d14056);cursor:pointer;text-decoration:none;font-weight:500}.request-fallback-link[data-v-6b6964f8]:hover{color:var(--ac-brand-primary-hover, #e55b70);text-decoration:underline}.connection-modal-wrap{overflow:hidden}
