import{P as h}from"./PlayerNavbar-ZFmVwlHh.js";import{e as _,V as b,r as y,b as k,f as w,q as u,j as v,k as L,s as t,Z as C,K as I,g as s,ar as P}from"./jwt-decode.esm-rEBc1yJt.js";import{u as N}from"./workspaceStore-CXj1KaxZ.js";import"./userStore-DeXNkqIg.js";import"./metadata-C1LHj-Qf.js";import"./PhWebhooksLogo.vue-ByF-2r3h.js";import"./PhHouse.vue-B8iXucbM.js";import"./PhMagnifyingGlass.vue-Gli9nbfd.js";import"./LoadingOutlined-BWNNCw0T.js";import"./PhSignOut.vue-Cn0w62FH.js";import"./index-DyX411wp.js";import"./runnerData-BmXXoqqr.js";import"./url-XyebHjIS.js";import"./colorHelpers-9BGi_4OL.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="b6a53976-4695-4cb7-9cfe-7ac1f35c75d8",o._sentryDebugIdIdentifier="sentry-dbid-b6a53976-4695-4cb7-9cfe-7ac1f35c75d8")}catch{}})();const V={class:"main-container"},B={class:"content"},D=_({__name:"Main",setup(o){const e=I(),a=b(),n=N(),p=a.path,r=y(null),d=async({path:c,id:i})=>{r.value=i,await e.push({path:`/${c}`}),r.value=null},l=()=>{e.push({name:"playerLogin"})},m=()=>{e.push({name:"playerLogin"})},f=k(()=>!!a.meta.hideLogin);return(c,i)=>{const g=C("RouterView");return s(),w("div",V,[t(n).state.workspace&&t(n).state.currentPageType!=="page"?(s(),u(h,{key:0,"current-path":t(p),"hide-login":f.value,"runner-data":t(n).state.workspace,loading:r.value,"show-sidebar":t(n).state.currentPageType==="form",onNavigate:d,onLoginClick:m,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):v("",!0),L("section",B,[(s(),u(g,{key:t(a).fullPath}))])])}}}),F=P(D,[["__scopeId","data-v-4b9b2f4b"]]);export{F as default};
//# sourceMappingURL=Main-Coz_UhKy.js.map
