import{C as e,_ as i}from"./View.vue_vue_type_script_setup_true_lang-BDByoy3Z.js";import{e as p,q as n,g as m,s}from"./jwt-decode.esm-rEBc1yJt.js";import{u as f}from"./projectStore-CqACsnK8.js";import"./router-BaFu-do7.js";import"./ts.worker-BI7fZ7sa.js";import"./fetch-10yPaR0B.js";import"./tables-DdYqLMX_.js";import"./string-BwJCihDb.js";import"./SaveButton-KdxrkcZm.js";import"./ExclamationCircleOutlined-slVpGEe4.js";import"./CrudView-BL69Sf1Y.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BDwFDFil.js";import"./constants-C-_YHHgQ.js";import"./url-XyebHjIS.js";import"./PhDotsThreeVertical.vue-BFQ8QBuw.js";import"./index-DK1hnqSz.js";import"./asyncComputed-r3mEZwQX.js";import"./PhPencil.vue-Bzy91iFg.js";import"./useCodebaseEvents-RQWkpOal.js";import"./codebaseEvents-CnQo2e5C.js";import"./contracts.generated-Df9OlTQX.js";import"./index-DAcqMusv.js";import"./member-qsE1qwIO.js";import"./project-D1d7g0j_.js";import"./organizationSwitcher-DLmZV2E5.js";import"./organization-DI9u_TkV.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="a23b2831-5cf8-42f8-98ff-db5b808444ec",o._sentryDebugIdIdentifier="sentry-dbid-a23b2831-5cf8-42f8-98ff-db5b808444ec")}catch{}})();const F=p({__name:"EnvVars",setup(o){const r=f(),t=new e(r.projectId);return(a,c)=>(m(),n(i,{"env-var-repository":s(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars-DpuTbLmy.js.map
