import{e as o,f as d,g as i,x as n,C as r,s as a,J as c,k as f,ar as l}from"./jwt-decode.esm-rEBc1yJt.js";import{R as _}from"./index-BNSvhqIi.js";import{C as u}from"./index-D9LKNmUT.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="18c25882-8f89-4b13-9434-7f4bb0ac7e4b",e._sentryDebugIdIdentifier="sentry-dbid-18c25882-8f89-4b13-9434-7f4bb0ac7e4b")}catch{}})();const b={class:"credentials-page"},p=o({__name:"CredentialsSuccessView",setup(e){return(s,t)=>(i(),d("div",b,[n(a(u),{class:"credentials-card"},{default:r(()=>[n(a(_),{title:a(c).translate("i18n_credential_form_thank_you")},{icon:r(()=>[...t[0]||(t[0]=[f("span",null,null,-1)])]),_:1},8,["title"])]),_:1})]))}}),w=l(p,[["__scopeId","data-v-f9bd641e"]]);export{w as default};
//# sourceMappingURL=CredentialsSuccessView-Dd13mKcR.js.map
