import{O as d}from"./workspaceStore-CXj1KaxZ.js";import{e as c,n as u,f as _,x as o,C as n,s as a,$ as f,a0 as p,S as r,T as s,J as i,g as b}from"./jwt-decode.esm-rEBc1yJt.js";import"./userStore-DeXNkqIg.js";import"./runnerData-BmXXoqqr.js";import"./url-XyebHjIS.js";import"./colorHelpers-9BGi_4OL.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c19ee24a-4106-4339-812b-8558cc674ed4",e._sentryDebugIdIdentifier="sentry-dbid-c19ee24a-4106-4339-812b-8558cc674ed4")}catch{}})();const x=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new d().logoutCallback()}),(t,l)=>(b(),_("div",null,[o(a(f),null,{default:n(()=>[r(s(a(i).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(s(a(i).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{x as default};
//# sourceMappingURL=OidcLogoutCallback-0pyp5ppt.js.map
