import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Bhh1Qoi3.js";import{B as y}from"./BaseLayout-CQmxhf6K.js";import{e as l,N as _,bF as b,ar as u,an as v,ao as g,g as m,f as h,k as a,v as s,n as w,K as S,q as k,C as n,V as B,x as i,s as I}from"./jwt-decode.esm-rEBc1yJt.js";import{u as $}from"./editor-BuPbv_2C.js";import{A as x}from"./index-Cz7iDKGt.js";import"./logo-BiWG9_W5.js";import"./Logo-BC2emGhq.js";import"./ts.worker-BI7fZ7sa.js";import"./workspaceStore-CXj1KaxZ.js";import"./userStore-DeXNkqIg.js";import"./runnerData-BmXXoqqr.js";import"./url-XyebHjIS.js";import"./colorHelpers-9BGi_4OL.js";import"./useCodebaseEvents-RQWkpOal.js";import"./codebaseEvents-CnQo2e5C.js";import"./contracts.generated-Df9OlTQX.js";import"./router-Der2W3lO.js";import"./constants-C-_YHHgQ.js";import"./files-D8DFVDfn.js";import"./index-DK1hnqSz.js";import"./index-DyX411wp.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="719771a3-ee5d-4919-9b0b-753263a4dcd6",e._sentryDebugIdIdentifier="sentry-dbid-719771a3-ee5d-4919-9b0b-753263a4dcd6")}catch{}})();const L=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),C={class:"v-spinner"};function D(e,r,o,d,c,p){return v((m(),h("div",C,[a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u(L,[["render",D],["__scopeId","data-v-224007fd"]]),P={class:"content"},R=l({__name:"ProjectLogin",setup(e){const r=B(),o=S(),d=$();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){o.push({name:"error"});return}await d.createLogin(t).then(c),o.push({name:"editor"})}),(t,z)=>(m(),k(y,null,{navbar:n(()=>[i(I(x),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[a("div",P,[i(K)])]),_:1}))}}),re=u(R,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-RbxExENw.js.map
