import{O as l}from"./workspaceStore-CXj1KaxZ.js";import{e as c,n as b,f,x as n,C as o,s as a,$ as u,a0 as _,S as r,T as s,J as i,g as p}from"./jwt-decode.esm-rEBc1yJt.js";import"./userStore-DeXNkqIg.js";import"./runnerData-BmXXoqqr.js";import"./url-XyebHjIS.js";import"./colorHelpers-9BGi_4OL.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8b5f4d18-476d-4505-b894-b12be0092bfb",e._sentryDebugIdIdentifier="sentry-dbid-8b5f4d18-476d-4505-b894-b12be0092bfb")}catch{}})();const x=c({__name:"OidcLoginCallback",setup(e){return b(async()=>{await new l().loginCallback()}),(t,d)=>(p(),f("div",null,[n(a(u),null,{default:o(()=>[r(s(a(i).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(_),null,{default:o(()=>[r(s(a(i).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{x as default};
//# sourceMappingURL=OidcLoginCallback-CuM6y2qE.js.map
