import{N as c}from"./Navbar-CklusjnV.js";import{e as d,V as u,b as a,J as l,Z as f,f as _,g as b,x as p,k as y,ar as I}from"./jwt-decode.esm-rEBc1yJt.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-CQ398DyA.js";import"./LoadingOutlined-BWNNCw0T.js";import"./constants-C-_YHHgQ.js";import"./PhCaretDown.vue-CQ-Fw2lE.js";import"./PhPencilSimple.vue-B26wpbsP.js";import"./router-BaFu-do7.js";import"./ts.worker-BI7fZ7sa.js";import"./organization-DI9u_TkV.js";import"./tables-DdYqLMX_.js";import"./string-BwJCihDb.js";import"./keyboard-BB3polz3.js";import"./os-D8ZgIrNR.js";import"./projectStore-CqACsnK8.js";import"./member-qsE1qwIO.js";import"./project-D1d7g0j_.js";import"./organizationSwitcher-DLmZV2E5.js";import"./cascaderStore-Dimdeu3o.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-CMvCJ8LW.js";import"./index-BYDOvbpL.js";import"./index-D9LKNmUT.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-EmXnbY8I.js";import"./PhNotePencil.vue-CTEwcN40.js";import"./avatarColor-DkHcfETa.js";import"./PhSignOut.vue-Cn0w62FH.js";import"./index-DK1hnqSz.js";import"./index-DyX411wp.js";import"./PhPlus.vue-Clm07SDU.js";import"./omniChatStore-DCXgFHA4.js";import"./contracts.generated-Df9OlTQX.js";import"./files-D8DFVDfn.js";import"./runnerData-BmXXoqqr.js";import"./url-XyebHjIS.js";import"./colorHelpers-9BGi_4OL.js";import"./uuid-DR3LYZRs.js";import"./PhCopySimple.vue-BI2p3-bP.js";import"./PhSparkle.vue-VsSOBqQ_.js";import"./index-Cz7iDKGt.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="2fc26ac7-7232-4eab-a9b3-08f021a0ab15",r._sentryDebugIdIdentifier="sentry-dbid-2fc26ac7-7232-4eab-a9b3-08f021a0ab15")}catch{}})();const g={class:"console-layout"},v={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return b(),_("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",v,[p(e)])])}}}),no=I(w,[["__scopeId","data-v-62f8634d"]]);export{no as default};
//# sourceMappingURL=ConsoleLayout-D1xOdFZS.js.map
