import{u as r}from"./userStore-DeXNkqIg.js";import{W as n}from"./PlayerConfigProvider-Cc_RHYBU.js";import{u as c}from"./workspaceStore-CXj1KaxZ.js";import{e as d,O as i,q as m,j as u,s as o,C as f,x as l,Z as p,g as w}from"./jwt-decode.esm-rEBc1yJt.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="0a9636ac-9ad2-47ed-9ab7-0a9cdb3d3d27",t._sentryDebugIdIdentifier="sentry-dbid-0a9636ac-9ad2-47ed-9ab7-0a9cdb3d3d27")}catch{}})();const C=d({__name:"App",setup(t){document.documentElement.dataset.theme="light";const a=r(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(_,g)=>{const s=p("RouterView");return o(e).state.workspace?(w(),m(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:f(()=>[l(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):u("",!0)}}});export{C as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang-CWnpQ8nn.js.map
