import{e as B,b as i,q as a,g as s,s as o,B as h,C as r,x as k,D as c,E as f,F as v,k as y,h as g,j as b,m as w}from"./jwt-decode.esm-rEBc1yJt.js";import{L as _}from"./LoadingOutlined-BWNNCw0T.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ee71c74f-2870-40e5-a660-8f1cfb758684",t._sentryDebugIdIdentifier="sentry-dbid-ee71c74f-2870-40e5-a660-8f1cfb758684")}catch{}})();const x={style:{display:"inline-flex","align-items":"center","justify-content":"center",gap:"5px"}},C={style:{display:"inline-flex","align-items":"center","justify-content":"center",gap:"5px"}},I=B({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){const e=t,l=i(()=>e.disabledTooltip&&e.disabled?e.disabledTooltip:e.tooltip),d=i(()=>!!e.loading),p=i(()=>{const{loading:n,disabled:u,...m}=e;return{...m,disabled:u||!!n}});return(n,u)=>l.value?(s(),a(o(h),{key:0,title:l.value},{default:r(()=>[k(o(c),f(v(p.value)),{default:r(()=>[y("span",x,[g(n.$slots,"default"),d.value?(s(),a(o(_),{key:0})):b("",!0)])]),_:3},16)]),_:3},8,["title"])):(s(),a(o(c),f(w({key:1},p.value)),{default:r(()=>[y("span",C,[g(n.$slots,"default"),d.value?(s(),a(o(_),{key:0})):b("",!0)])]),_:3},16))}});export{I as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang-CQ398DyA.js.map
