import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-q3tIvuH_.js";import{e as d,f as i,x as u,s as n,K as m,V as l,g as f,ar as _}from"./jwt-decode.esm-rEBc1yJt.js";import{u as b}from"./workspaceStore-CXj1KaxZ.js";import"./OTPInput-DhtFXN2j.js";import"./Logo-BC2emGhq.js";import"./string-BwJCihDb.js";import"./CircularLoading-C_mYUEPg.js";import"./index-DAcqMusv.js";import"./userStore-DeXNkqIg.js";import"./runnerData-BmXXoqqr.js";import"./url-XyebHjIS.js";import"./colorHelpers-9BGi_4OL.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b9a979fe-3b33-415a-9bc5-5c5b04d4d3e2",e._sentryDebugIdIdentifier="sentry-dbid-b9a979fe-3b33-415a-9bc5-5c5b04d4d3e2")}catch{}})();const g={class:"runner"},y=d({__name:"Login",setup(e){const o=m(),r=l(),t=b(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(f(),i("div",g,[u(p,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-CYmeaUY3.js.map
