import{e as f,K as _,V as m,J as s,q as p,g as b,C as c,f as g,W as y,X as v,x as k,s as n,k as w,T as I}from"./jwt-decode.esm-rEBc1yJt.js";import{u as T}from"./projectStore-CqACsnK8.js";import{A as D,T as S}from"./index-D9LKNmUT.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3c2b5a8f-896f-4bb1-8708-424c25b8f61e",e._sentryDebugIdIdentifier="sentry-dbid-3c2b5a8f-896f-4bb1-8708-424c25b8f61e")}catch{}})();const q=f({__name:"TablesTabs",setup(e){const a=_(),r=m(),i=String(r.name),u=T(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],d=l=>{a.push({name:String(l),params:{projectId:u.projectId}})};return(l,h)=>(b(),p(n(S),{"active-key":n(i),options:o,"onUpdate:activeKey":d},{default:c(()=>[(b(),g(y,null,v(o,t=>k(n(D),{key:t.value,name:t.value},{tab:c(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{q as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-CavozqcO.js.map
