const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-CuM6y2qE.js","assets/workspaceStore-CXj1KaxZ.js","assets/jwt-decode.esm-rEBc1yJt.js","assets/jwt-decode-D2NJgJx6.css","assets/userStore-DeXNkqIg.js","assets/runnerData-BmXXoqqr.js","assets/url-XyebHjIS.js","assets/colorHelpers-9BGi_4OL.js","assets/OidcLogoutCallback-0pyp5ppt.js","assets/Login-CYmeaUY3.js","assets/Login.vue_vue_type_script_setup_true_lang-q3tIvuH_.js","assets/OTPInput-DhtFXN2j.js","assets/OTPInput-DkitIIgo.css","assets/Logo-BC2emGhq.js","assets/Logo-D2kepPyK.css","assets/string-BwJCihDb.js","assets/CircularLoading-C_mYUEPg.js","assets/CircularLoading-BiyobKo3.css","assets/index-DAcqMusv.js","assets/Login-CmviQBec.css","assets/Login-CSLF5y6q.css","assets/Main-Coz_UhKy.js","assets/PlayerNavbar-ZFmVwlHh.js","assets/metadata-C1LHj-Qf.js","assets/PhWebhooksLogo.vue-ByF-2r3h.js","assets/PhHouse.vue-B8iXucbM.js","assets/PhMagnifyingGlass.vue-Gli9nbfd.js","assets/LoadingOutlined-BWNNCw0T.js","assets/PhSignOut.vue-Cn0w62FH.js","assets/index-DyX411wp.js","assets/PlayerNavbar-DAUZYUrK.css","assets/Main-BUjGuAbV.css","assets/Home-BVxZ-DGj.js","assets/Watermark-ShqNe1r1.js","assets/constants-C-_YHHgQ.js","assets/Watermark-C-v8lywQ.css","assets/PageStageView-Q2JkJBjk.js","assets/consoleCapture-B0hRvrGL.js","assets/PageStageView-dZcfz7zQ.css","assets/PhArrowSquareOut.vue-xDhGWjq7.js","assets/index-D9LKNmUT.js","assets/Home-DoQD4uFs.css","assets/Error-Bt5tfBNi.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-Bhh1Qoi3.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-BGK_XChy.js","assets/FormRunner-DiEra5eD.js","assets/Steps-TR6GZ6v3.js","assets/index-CqNRy1DZ.js","assets/Steps-mRTkp5g4.css","assets/FormRunner-CnnhHAy4.css","assets/redirect-CfeLb0iW.js","assets/asyncComputed-r3mEZwQX.js","assets/uuid-DR3LYZRs.js","assets/Form-TwePofFo.css"])))=>i.map(i=>d[i]);
import{c as u,a as d,_ as t,u as l}from"./jwt-decode.esm-rEBc1yJt.js";import{u as p}from"./userStore-DeXNkqIg.js";import{a as _}from"./workspaceStore-CXj1KaxZ.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cf5accf6-aeb8-4ec9-818d-b0c15c139299",e._sentryDebugIdIdentifier="sentry-dbid-cf5accf6-aeb8-4ec9-818d-b0c15c139299")}catch{}})();const h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-CuM6y2qE.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-0pyp5ppt.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-CYmeaUY3.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-Coz_UhKy.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30,31])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-BVxZ-DGj.js"),__vite__mapDeps([32,23,24,2,3,25,26,33,1,4,5,6,7,34,35,36,16,17,37,38,39,40,27,41])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-Bt5tfBNi.js"),__vite__mapDeps([42,43,44,13,2,3,14,34,1,4,5,6,7,40,45])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-BGK_XChy.js"),__vite__mapDeps([46,4,2,3,36,16,17,33,1,5,6,7,34,35,37,38,47,10,11,12,13,14,15,18,19,48,49,50,51,52,53,54,55])),meta:{hideLogin:!0}}]}],i=u({history:d("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...m}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...m,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as g,i as r};
//# sourceMappingURL=router-Der2W3lO.js.map
