.subdomain-editor[data-v-5af3ec8d],.subdomain-editor__inner[data-v-5af3ec8d]{width:100%}.subdomain-editor__section-title[data-v-5af3ec8d]{margin-top:0!important;margin-bottom:12px!important}.subdomain-editor__divider[data-v-5af3ec8d]{margin:0!important}.subdomain-editor__block[data-v-5af3ec8d]{width:100%}.subdomain-editor__label[data-v-5af3ec8d]{display:block;margin-bottom:4px}.subdomain-editor__mono[data-v-5af3ec8d]{margin-bottom:0}.subdomain-editor__mono[data-v-5af3ec8d] .ant-typography{word-break:break-all}.subdomain-editor__email-intro[data-v-5af3ec8d],.subdomain-editor__lead[data-v-5af3ec8d]{margin-bottom:16px}.subdomain-editor__subdomain-input[data-v-5af3ec8d],.project-status-card[data-v-dcd7b7e1],.project-status-card__inner[data-v-dcd7b7e1]{width:100%}.project-status-card__lead[data-v-dcd7b7e1]{margin-bottom:0}.project-status-card__confirm[data-v-dcd7b7e1]{display:inline-block;max-width:300px}.project-settings[data-v-b78d1992]{max-width:52rem;padding-bottom:48px}.project-settings__title[data-v-b78d1992]{margin-bottom:24px!important}.project-settings__cards[data-v-b78d1992]{width:100%}
