.credentials-page[data-v-7ab45bd7]{min-height:100vh;display:flex;align-items:center;justify-content:center;padding:20px;background-color:var(--ac-surface-secondary, #f5f5f5)}.loading-container[data-v-7ab45bd7],.error-container[data-v-7ab45bd7]{display:flex;align-items:center;justify-content:center;min-height:400px}.credentials-card[data-v-7ab45bd7]{max-width:500px;width:100%}.error-container[data-v-7ab45bd7] .ant-result-title,.error-container[data-v-7ab45bd7] .ant-result-extra,.error-text[data-v-7ab45bd7]{color:#000!important}
