import{e as o,b as s,f as l,g as r,k as i,h as u,v as c,t as a,ar as f}from"./jwt-decode.esm-rEBc1yJt.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="58a7531d-b869-4265-a554-df34dca7609b",e._sentryDebugIdIdentifier="sentry-dbid-58a7531d-b869-4265-a554-df34dca7609b")}catch{}})();const y=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(d,g)=>(r(),l("div",{class:a(["content-layout",{"no-padding":e.noPadding}])},[i("div",{class:a(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:c(t.value)},[u(d.$slots,"default",{},void 0,!0)],6)],2))}}),b=f(y,[["__scopeId","data-v-00e066e8"]]);export{b as C};
//# sourceMappingURL=ContentLayout-30I764NL.js.map
